#[repr(i32)]pub enum NodeRole {
Unspecified = 0,
Worker = 1,
Host = 2,
Client = 3,
}Expand description
Shared enum
Variants
Implementations
Sourceimpl NodeRole
impl NodeRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<NodeRole>
pub fn from_str_name(value: &str) -> Option<NodeRole>
Creates an enum from field names used in the ProtoBuf definition.