#[repr(i32)]pub enum OwnerControlErrorCode {
Unspecified = 0,
BadRequest = 1,
Unauthorized = 2,
RevisionConflict = 3,
ControlUnsupported = 4,
ControlEndpointRequired = 5,
ControlUnavailable = 6,
UnknownCommand = 7,
LegacyJsonUnsupported = 8,
InvalidHandshake = 9,
TargetNodeMismatch = 10,
}Variants
Unspecified = 0
BadRequest = 1
RevisionConflict = 3
ControlUnsupported = 4
ControlEndpointRequired = 5
UnknownCommand = 7
LegacyJsonUnsupported = 8
InvalidHandshake = 9
TargetNodeMismatch = 10
Implementations
Sourceimpl OwnerControlErrorCode
impl OwnerControlErrorCode
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of OwnerControlErrorCode.
Sourcepub fn from_i32(value: i32) -> Option<OwnerControlErrorCode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OwnerControlErrorCode>
Use the TryFrom<i32> implementation instead
Converts an i32 to a OwnerControlErrorCode, or None if value is not a valid variant.
Sourceimpl OwnerControlErrorCode
impl OwnerControlErrorCode
pub fn as_str_name(&self) -> &'static str
pub fn from_str_name(value: &str) -> Option<OwnerControlErrorCode>