pub struct ModelCapabilities {
pub vision: i32,
pub reasoning: i32,
pub tool_use: i32,
pub moe: bool,
pub multimodal: bool,
pub audio: i32,
}Fields
vision: i32reasoning: i32tool_use: i32moe: boolmultimodal: boolaudio: i32Implementations
Sourceimpl ModelCapabilities
impl ModelCapabilities
Sourcepub fn vision(&self) -> CapabilityLevel
pub fn vision(&self) -> CapabilityLevel
Returns the enum value of vision, or the default if the field is set to an invalid enum value.
Sourcepub fn set_vision(&mut self, value: CapabilityLevel)
pub fn set_vision(&mut self, value: CapabilityLevel)
Sets vision to the provided enum value.
Sourcepub fn reasoning(&self) -> CapabilityLevel
pub fn reasoning(&self) -> CapabilityLevel
Returns the enum value of reasoning, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reasoning(&mut self, value: CapabilityLevel)
pub fn set_reasoning(&mut self, value: CapabilityLevel)
Sets reasoning to the provided enum value.
Sourcepub fn tool_use(&self) -> CapabilityLevel
pub fn tool_use(&self) -> CapabilityLevel
Returns the enum value of tool_use, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tool_use(&mut self, value: CapabilityLevel)
pub fn set_tool_use(&mut self, value: CapabilityLevel)
Sets tool_use to the provided enum value.
Sourcepub fn audio(&self) -> CapabilityLevel
pub fn audio(&self) -> CapabilityLevel
Returns the enum value of audio, or the default if the field is set to an invalid enum value.
Sourcepub fn set_audio(&mut self, value: CapabilityLevel)
pub fn set_audio(&mut self, value: CapabilityLevel)
Sets audio to the provided enum value.