pub struct OwnerControlApplyConfigRequest {
pub requester_node_id: Vec<u8>,
pub target_node_id: Vec<u8>,
pub expected_revision: u64,
pub config: Option<NodeConfigSnapshot>,
}Fields
requester_node_id: Vec<u8>exactly 32 bytes
target_node_id: Vec<u8>exactly 32 bytes
expected_revision: u64config: Option<NodeConfigSnapshot>Trait Implementations
Sourceimpl Clone for OwnerControlApplyConfigRequest
impl Clone for OwnerControlApplyConfigRequest
Sourcefn clone(&self) -> OwnerControlApplyConfigRequest
fn clone(&self) -> OwnerControlApplyConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for OwnerControlApplyConfigRequest
impl Default for OwnerControlApplyConfigRequest
Sourcefn default() -> OwnerControlApplyConfigRequest
fn default() -> OwnerControlApplyConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlApplyConfigRequest
impl Message for OwnerControlApplyConfigRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerControlApplyConfigRequest
impl PartialEq for OwnerControlApplyConfigRequest
Sourcefn eq(&self, other: &OwnerControlApplyConfigRequest) -> bool
fn eq(&self, other: &OwnerControlApplyConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValidateControlFrame for OwnerControlApplyConfigRequest
impl ValidateControlFrame for OwnerControlApplyConfigRequest
fn validate_frame(&self) -> Result<(), ControlFrameError>
impl StructuralPartialEq for OwnerControlApplyConfigRequest