pub struct OwnerControlApplyConfigResponse {
pub success: bool,
pub current_revision: u64,
pub config_hash: Vec<u8>,
pub error: Option<String>,
pub apply_mode: i32,
}Fields
success: boolcurrent_revision: u64config_hash: Vec<u8>error: Option<String>apply_mode: i32Implementations
Sourceimpl OwnerControlApplyConfigResponse
impl OwnerControlApplyConfigResponse
Sourcepub fn error(&self) -> &str
pub fn error(&self) -> &str
Returns the value of error, or the default value if error is unset.
Sourcepub fn apply_mode(&self) -> ConfigApplyMode
pub fn apply_mode(&self) -> ConfigApplyMode
Returns the enum value of apply_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_apply_mode(&mut self, value: ConfigApplyMode)
pub fn set_apply_mode(&mut self, value: ConfigApplyMode)
Sets apply_mode to the provided enum value.