pub struct OwnerControlConfigUpdate {
pub node_id: Vec<u8>,
pub revision: u64,
pub config_hash: Vec<u8>,
pub config: Option<NodeConfigSnapshot>,
}Fields
node_id: Vec<u8>exactly 32 bytes
revision: u64config_hash: Vec<u8>SHA-256 of canonical proto bytes (32 bytes)
config: Option<NodeConfigSnapshot>Trait Implementations
Sourceimpl Clone for OwnerControlConfigUpdate
impl Clone for OwnerControlConfigUpdate
Sourcefn clone(&self) -> OwnerControlConfigUpdate
fn clone(&self) -> OwnerControlConfigUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnerControlConfigUpdate
impl Debug for OwnerControlConfigUpdate
Sourceimpl Default for OwnerControlConfigUpdate
impl Default for OwnerControlConfigUpdate
Sourcefn default() -> OwnerControlConfigUpdate
fn default() -> OwnerControlConfigUpdate
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlConfigUpdate
impl Message for OwnerControlConfigUpdate
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerControlConfigUpdate
impl PartialEq for OwnerControlConfigUpdate
Sourcefn eq(&self, other: &OwnerControlConfigUpdate) -> bool
fn eq(&self, other: &OwnerControlConfigUpdate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValidateControlFrame for OwnerControlConfigUpdate
impl ValidateControlFrame for OwnerControlConfigUpdate
fn validate_frame(&self) -> Result<(), ControlFrameError>
impl StructuralPartialEq for OwnerControlConfigUpdate