pub struct OwnerControlEnvelope {
pub gen: u32,
pub handshake: Option<OwnerControlHandshake>,
pub request: Option<OwnerControlRequest>,
pub response: Option<OwnerControlResponse>,
pub error: Option<OwnerControlError>,
}Fields
gen: u32must equal NODE_PROTOCOL_GENERATION
handshake: Option<OwnerControlHandshake>request: Option<OwnerControlRequest>response: Option<OwnerControlResponse>error: Option<OwnerControlError>Trait Implementations
Sourceimpl Clone for OwnerControlEnvelope
impl Clone for OwnerControlEnvelope
Sourcefn clone(&self) -> OwnerControlEnvelope
fn clone(&self) -> OwnerControlEnvelope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnerControlEnvelope
impl Debug for OwnerControlEnvelope
Sourceimpl Default for OwnerControlEnvelope
impl Default for OwnerControlEnvelope
Sourcefn default() -> OwnerControlEnvelope
fn default() -> OwnerControlEnvelope
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlEnvelope
impl Message for OwnerControlEnvelope
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerControlEnvelope
impl PartialEq for OwnerControlEnvelope
Sourcefn eq(&self, other: &OwnerControlEnvelope) -> bool
fn eq(&self, other: &OwnerControlEnvelope) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValidateControlFrame for OwnerControlEnvelope
impl ValidateControlFrame for OwnerControlEnvelope
fn validate_frame(&self) -> Result<(), ControlFrameError>
impl StructuralPartialEq for OwnerControlEnvelope