pub struct OwnerControlError {
pub code: i32,
pub message: String,
pub request_id: Option<u64>,
pub current_revision: Option<u64>,
}Fields
code: i32message: Stringrequest_id: Option<u64>current_revision: Option<u64>Implementations
Sourceimpl OwnerControlError
impl OwnerControlError
Sourcepub fn code(&self) -> OwnerControlErrorCode
pub fn code(&self) -> OwnerControlErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: OwnerControlErrorCode)
pub fn set_code(&mut self, value: OwnerControlErrorCode)
Sets code to the provided enum value.
Sourcepub fn request_id(&self) -> u64
pub fn request_id(&self) -> u64
Returns the value of request_id, or the default value if request_id is unset.
Sourcepub fn current_revision(&self) -> u64
pub fn current_revision(&self) -> u64
Returns the value of current_revision, or the default value if current_revision is unset.