pub struct OwnerControlRefreshInventory {
pub entries: Vec<OwnerControlInventoryEntry>,
pub disposition: i32,
}Fields
entries: Vec<OwnerControlInventoryEntry>disposition: i32Implementations
Sourceimpl OwnerControlRefreshInventory
impl OwnerControlRefreshInventory
Sourcepub fn disposition(&self) -> OwnerControlRefreshInventoryDisposition
pub fn disposition(&self) -> OwnerControlRefreshInventoryDisposition
Returns the enum value of disposition, or the default if the field is set to an invalid enum value.
Sourcepub fn set_disposition(
&mut self,
value: OwnerControlRefreshInventoryDisposition,
)
pub fn set_disposition( &mut self, value: OwnerControlRefreshInventoryDisposition, )
Sets disposition to the provided enum value.