pub struct OwnerControlRequest {
pub request_id: u64,
pub get_config: Option<OwnerControlGetConfigRequest>,
pub watch_config: Option<OwnerControlWatchConfigRequest>,
pub apply_config: Option<OwnerControlApplyConfigRequest>,
pub refresh_inventory: Option<OwnerControlRefreshInventoryRequest>,
}Fields
request_id: u64get_config: Option<OwnerControlGetConfigRequest>watch_config: Option<OwnerControlWatchConfigRequest>apply_config: Option<OwnerControlApplyConfigRequest>refresh_inventory: Option<OwnerControlRefreshInventoryRequest>Trait Implementations
Sourceimpl Clone for OwnerControlRequest
impl Clone for OwnerControlRequest
Sourcefn clone(&self) -> OwnerControlRequest
fn clone(&self) -> OwnerControlRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnerControlRequest
impl Debug for OwnerControlRequest
Sourceimpl Default for OwnerControlRequest
impl Default for OwnerControlRequest
Sourcefn default() -> OwnerControlRequest
fn default() -> OwnerControlRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlRequest
impl Message for OwnerControlRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerControlRequest
impl PartialEq for OwnerControlRequest
Sourcefn eq(&self, other: &OwnerControlRequest) -> bool
fn eq(&self, other: &OwnerControlRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValidateControlFrame for OwnerControlRequest
impl ValidateControlFrame for OwnerControlRequest
fn validate_frame(&self) -> Result<(), ControlFrameError>
impl StructuralPartialEq for OwnerControlRequest