pub struct OwnerControlResponse {
pub request_id: u64,
pub get_config: Option<OwnerControlGetConfigResponse>,
pub watch_config: Option<OwnerControlWatchConfigResponse>,
pub apply_config: Option<OwnerControlApplyConfigResponse>,
pub refresh_inventory: Option<OwnerControlRefreshInventoryResponse>,
}Fields
request_id: u64get_config: Option<OwnerControlGetConfigResponse>watch_config: Option<OwnerControlWatchConfigResponse>apply_config: Option<OwnerControlApplyConfigResponse>refresh_inventory: Option<OwnerControlRefreshInventoryResponse>Trait Implementations
Sourceimpl Clone for OwnerControlResponse
impl Clone for OwnerControlResponse
Sourcefn clone(&self) -> OwnerControlResponse
fn clone(&self) -> OwnerControlResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnerControlResponse
impl Debug for OwnerControlResponse
Sourceimpl Default for OwnerControlResponse
impl Default for OwnerControlResponse
Sourcefn default() -> OwnerControlResponse
fn default() -> OwnerControlResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlResponse
impl Message for OwnerControlResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerControlResponse
impl PartialEq for OwnerControlResponse
Sourcefn eq(&self, other: &OwnerControlResponse) -> bool
fn eq(&self, other: &OwnerControlResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValidateControlFrame for OwnerControlResponse
impl ValidateControlFrame for OwnerControlResponse
fn validate_frame(&self) -> Result<(), ControlFrameError>
impl StructuralPartialEq for OwnerControlResponse