pub struct OwnerControlUnloadModelRequest {
pub requester_node_id: Vec<u8>,
pub target_node_id: Vec<u8>,
pub model: Option<OwnerControlModelRef>,
}Fields
requester_node_id: Vec<u8>target_node_id: Vec<u8>model: Option<OwnerControlModelRef>Trait Implementations
Sourceimpl Clone for OwnerControlUnloadModelRequest
impl Clone for OwnerControlUnloadModelRequest
Sourcefn clone(&self) -> OwnerControlUnloadModelRequest
fn clone(&self) -> OwnerControlUnloadModelRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for OwnerControlUnloadModelRequest
impl Default for OwnerControlUnloadModelRequest
Sourcefn default() -> OwnerControlUnloadModelRequest
fn default() -> OwnerControlUnloadModelRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlUnloadModelRequest
impl Message for OwnerControlUnloadModelRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for OwnerControlUnloadModelRequest
Sourceimpl ValidateControlFrame for OwnerControlUnloadModelRequest
impl ValidateControlFrame for OwnerControlUnloadModelRequest
fn validate_frame(&self) -> Result<(), ControlFrameError>