pub struct OwnerControlWatchConfigRequest {
pub requester_node_id: Vec<u8>,
pub target_node_id: Vec<u8>,
pub include_snapshot: bool,
}Fields
requester_node_id: Vec<u8>exactly 32 bytes
target_node_id: Vec<u8>exactly 32 bytes
include_snapshot: boolTrait Implementations
Sourceimpl Clone for OwnerControlWatchConfigRequest
impl Clone for OwnerControlWatchConfigRequest
Sourcefn clone(&self) -> OwnerControlWatchConfigRequest
fn clone(&self) -> OwnerControlWatchConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for OwnerControlWatchConfigRequest
impl Default for OwnerControlWatchConfigRequest
Sourcefn default() -> OwnerControlWatchConfigRequest
fn default() -> OwnerControlWatchConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for OwnerControlWatchConfigRequest
impl Message for OwnerControlWatchConfigRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerControlWatchConfigRequest
impl PartialEq for OwnerControlWatchConfigRequest
Sourcefn eq(&self, other: &OwnerControlWatchConfigRequest) -> bool
fn eq(&self, other: &OwnerControlWatchConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValidateControlFrame for OwnerControlWatchConfigRequest
impl ValidateControlFrame for OwnerControlWatchConfigRequest
fn validate_frame(&self) -> Result<(), ControlFrameError>
impl StructuralPartialEq for OwnerControlWatchConfigRequest