pub struct ServedModelIdentity {
pub model_name: String,
pub is_primary: bool,
pub source_kind: i32,
pub canonical_ref: Option<String>,
pub repository: Option<String>,
pub revision: Option<String>,
pub artifact: Option<String>,
pub local_file_name: Option<String>,
pub identity_hash: Option<String>,
}Fields
model_name: Stringis_primary: boolsource_kind: i32canonical_ref: Option<String>repository: Option<String>revision: Option<String>artifact: Option<String>local_file_name: Option<String>identity_hash: Option<String>Implementations
Sourceimpl ServedModelIdentity
impl ServedModelIdentity
Sourcepub fn source_kind(&self) -> ModelSourceKind
pub fn source_kind(&self) -> ModelSourceKind
Returns the enum value of source_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source_kind(&mut self, value: ModelSourceKind)
pub fn set_source_kind(&mut self, value: ModelSourceKind)
Sets source_kind to the provided enum value.
Sourcepub fn canonical_ref(&self) -> &str
pub fn canonical_ref(&self) -> &str
Returns the value of canonical_ref, or the default value if canonical_ref is unset.
Sourcepub fn repository(&self) -> &str
pub fn repository(&self) -> &str
Returns the value of repository, or the default value if repository is unset.
Sourcepub fn revision(&self) -> &str
pub fn revision(&self) -> &str
Returns the value of revision, or the default value if revision is unset.
Sourcepub fn artifact(&self) -> &str
pub fn artifact(&self) -> &str
Returns the value of artifact, or the default value if artifact is unset.
Sourcepub fn local_file_name(&self) -> &str
pub fn local_file_name(&self) -> &str
Returns the value of local_file_name, or the default value if local_file_name is unset.
Sourcepub fn identity_hash(&self) -> &str
pub fn identity_hash(&self) -> &str
Returns the value of identity_hash, or the default value if identity_hash is unset.